.. currentmodule:: disnake_compass.impl

Builtins Parser Implementations
===============================

.. automodule:: disnake_compass.impl.parser.builtins


Classes
-------

.. attributetable:: disnake_compass.impl.parser.builtins.NoneParser

.. autoclass:: disnake_compass.impl.parser.builtins.NoneParser
    :members:

.. attributetable:: disnake_compass.impl.parser.builtins.FloatParser

.. autoclass:: disnake_compass.impl.parser.builtins.FloatParser
    :members:

.. attributetable:: disnake_compass.impl.parser.builtins.IntParser

.. autoclass:: disnake_compass.impl.parser.builtins.IntParser
    :members:

.. attributetable:: disnake_compass.impl.parser.builtins.BoolParser

.. autoclass:: disnake_compass.impl.parser.builtins.BoolParser
    :members:

.. attributetable:: disnake_compass.impl.parser.builtins.StringParser

.. autoclass:: disnake_compass.impl.parser.builtins.StringParser
    :members:

.. attributetable:: disnake_compass.impl.parser.builtins.TupleParser

.. autoclass:: disnake_compass.impl.parser.builtins.TupleParser
    :members:

.. attributetable:: disnake_compass.impl.parser.builtins.CollectionParser

.. autoclass:: disnake_compass.impl.parser.builtins.CollectionParser
    :members:

.. attributetable:: disnake_compass.impl.parser.builtins.UnionParser

.. autoclass:: disnake_compass.impl.parser.builtins.UnionParser
    :members:
